.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Welcome

   welcome/install
   welcome/docker

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Explain

   explain/rationale
   explain/entities_overview
   explain/pipelines
   explain/nodes
   explain/messages
   explain/remote

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: How To

    how_to/why_how
    how_to/create_nodes
    how_to/create_pipelines
    how_to/use_cli
    how_to/environment
    how_to/remotise_node
    how_to/observe

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Create

    create/real_world
    create/audio_transcription
    create/video_yolo

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Built-in nodes

    built_in/overview.rst
    built_in/builtin

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: References

    apis/explore
    apis/modules

|version-badge|

Juturna's documentation
=======================

.. .. image:: ./_static/img/logo_dark_alt_transparent.svg
..    :alt: juturna
..    :width: 30%
..    :align: center

.. \

.. image:: https://img.shields.io/github/license/meetecho/juturna?style=for-the-badge
    :alt: License

.. image:: https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fmeetecho%2Fjuturna%2Frefs%2Fheads%2Fmain%2Fpyproject.toml&style=for-the-badge&color=green
   :alt: Python Version from PEP 621 TOML

.. image:: https://img.shields.io/github/stars/meetecho/juturna?style=for-the-badge
    :alt: Stars

.. image:: https://img.shields.io/github/forks/meetecho/juturna?style=for-the-badge
    :alt: Forks

.. image:: https://img.shields.io/github/issues/meetecho/juturna?style=for-the-badge
    :alt: Issues

----

Energise your multimedia data prototyping with **Juturna**: design, implement,
execute and manipulate real-time pipelines in minutes!

.. grid:: 2

    .. grid-item::
        .. card:: ``jt/explain``
            :link: rationale
            :link-type: ref

            Unfold the basic concepts behind Juturna, including its core working
            principles and internals.

    .. grid-item::
        .. card:: ``jt/how_to``
            :link: howto
            :link-type: ref

            Deep dive into common tasks and usage scenarios you may face when
            using Juturna.

.. grid:: 2

    .. grid-item::
        .. card:: ``jt/build``
            :link: realworld
            :link-type: ref

            Get your hands dirty with practical guides to see Juturna in action
            on real-world problems!

    .. grid-item::
        .. card:: ``jt/apis``
            :link: reference
            :link-type: ref

            Check out the code documentation and the Juturna Python APIs
            reference, or explore the GitHub repository.

.. grid:: 1

    .. grid-item::

            .. card::
                :text-align: center

                :fas:`meetecho`

                Juturna is brewed with love by the awesome team of
                `Meetecho <https://www.meetecho.com/en/>`_. Come and say hi!

Take a look at the `GitHub project <https://github.com/meetecho/juturna>`_ if
you want to explore the code.

Feel like contributing? Please refer to our
`guidelines <https://github.com/meetecho/juturna/blob/main/CONTRIBUTING.md>`_.
